@@ -133,11 +133,13 @@ PositionCenterSpoke <- ggplot2::ggproto("PositionCenterSpoke", ggplot2::Position
 #'
 #' Uniformly distributed orientations should yield a straight line through the
 #' origin. Systematic departures from linearity will indicate preferred
-#' orientation in some manner.
+#' orientation.
 #'
 #' @param x numeric. Angles in degrees
 #' @param axial Logical. Whether data are uniaxial (`axial=FALSE`)
 #' @param xlab,ylab,main plot labels.
+#' @param col color for the dots.
+#' @param add_line logical. Whether to connect the points by straight lines?
 #' @param ... graphical parameters
 #'
 #' @return plot
@@ -149,17 +151,21 @@ PositionCenterSpoke <- ggplot2::ggproto("PositionCenterSpoke", ggplot2::Position
 #' p. 329). Berlin: Springer.
 #'
 #' @examples
+#' # von Mises distribution
 #' x_vm <- rvm(100, mean = 0, kappa = 2)
 #' circular_qqplot(x_vm, pch = 20)
 #'
 #' x_norm <- rnorm(100, mean = 0, sd = 25)
 #' circular_qqplot(x_norm, pch = 20)
 #'
+#' # uniform (random) data
 #' x_unif <- runif(100, 0, 360)
 #' circular_qqplot(x_unif, pch = 20)
 circular_qqplot <- function(x, axial = TRUE,
                             xlab = paste("i/(n+1)"),
-                            ylab = NULL, main = "Circular Quantile-Quantile Plot", ...) {
+                            ylab = NULL, main = "Circular Quantile-Quantile Plot",
+                            add_line = TRUE,
+                            col = "#B63679FF", ...) {
   if (axial) {
     f <- 2
   } else {
@@ -174,14 +180,17 @@ circular_qqplot <- function(x, axial = TRUE,
   n <- length(x)
   xin <- seq_along(x) / (n + 1)
 
-  graphics::plot(xin, x,
-    type = "p", xlim = c(0, 1), ylim = c(0, 1), asp = 1,
-    xlab = xlab, ylab = ylab, main = main,
-    sub = bquote("N" == .(n)),
-    ...
+  graphics::plot(1,
+    type = "n", xlim = c(0, 1), ylim = c(0, 1), asp = 1,
+    xlab = xlab, ylab = ylab
   )
   graphics::abline(a = 0, b = 1, col = "slategrey")
-  graphics::lines(xin, x)
+  if (add_line) {
+    graphics::lines(xin, x)
+  }
+  graphics::points(xin, x, col = col, ...)
+  graphics::title(main = main, sub = bquote("N" == .(n)))
+
   invisible(xin)
   # graphics::points(xin, x, col = "slategrey")
 }
@@ -199,6 +208,8 @@ circular_qqplot <- function(x, axial = TRUE,
 #' it will be estimated from `x`.
 #' @param kappa numeric. Concentration parameter of the von Mises distribution.
 #' If `NULL`, it will be estimated from `x`.
+#' @param col color for the dots.
+#' @param add_line logical. Whether to connect the points by straight lines?
 #' @param ... graphical parameters
 #'
 #' @return plot
@@ -208,15 +219,18 @@ circular_qqplot <- function(x, axial = TRUE,
 #' @export
 #'
 #' @examples
+#' # von Mises distribution
 #' x_vm <- rvm(100, mean = 0, kappa = 4)
 #' vm_qqplot(x_vm, axial = FALSE, pch = 20)
 #'
+#' # uniform distribution
 #' x_unif <- runif(100, 0, 360)
 #' vm_qqplot(x_unif, axial = FALSE, pch = 20)
 vm_qqplot <- function(x, w = NULL, axial = TRUE, mean = NULL, kappa = NULL,
                       xlab = "von Mises quantile function",
                       ylab = "Empirical quantile function",
-                      main = "von Mises Q-Q Plot", ...) {
+                      main = "von Mises Q-Q Plot",
+                      col = "#B63679FF", add_line = TRUE, ...) {
   if (axial) {
     f <- 2
   } else {
@@ -235,7 +249,7 @@ vm_qqplot <- function(x, w = NULL, axial = TRUE, mean = NULL, kappa = NULL,
   if (is.null(kappa)) kappa <- est.kappa(x, w = w, axial = axial)
 
   caption <- bquote(
-    bar(alpha) == .(round(mean, 1)) * degree ~ "|" ~ kappa == .(round(kappa, 1))
+    bar(alpha) == .(round(mean, 1)) * degree ~ "|" ~ widehat(kappa) == .(round(kappa, 1))
   )
 
   xf <- (x * f) %% 360
@@ -261,10 +275,15 @@ vm_qqplot <- function(x, w = NULL, axial = TRUE, mean = NULL, kappa = NULL,
   # graphics::points(sin_q, z_sort, pch=20)
 
   tqf <- qvm(edf(xf), mean * f, kappa, from = 0)
-  #
-  graphics::plot(tqf / f, xf / f, xlim = c(0, 360 / f), ylim = c(0, 360 / f), asp = 1, xlab = xlab, ylab = ylab, main = main, sub = bquote("N" == .(n)), ...)
+
+  graphics::plot(1, type = "n", xlab = xlab, ylab = ylab, xlim = c(0, 360 / f), ylim = c(0, 360 / f))
   graphics::abline(a = 0, b = 1, col = "slategrey")
-  mtext(caption)
+  if (add_line) {
+    graphics::lines(tqf / f, xf / f)
+  }
+  graphics::points(tqf / f, xf / f, col = col, ...)
+  graphics::mtext(caption, cex = .75)
+  graphics::title(main = main, sub = bquote("N" == .(n)))
   invisible(tqf)
 }
 
@@ -481,6 +500,13 @@ add_end <- function(x, end) {
   }
 }
 
+rose_grid <- function(angles, radii, add = TRUE) {
+  rose_line(angles, col = "grey80", lty = 2, add = add)
+  for (i in radii) {
+    plot(spatstat.geom::disc(i), col = NA, border = "grey80", lty = 2, add = add)
+  }
+}
+
 #' @title Rose Diagram
 #'
 #' @description Plots a rose diagram (rose of directions), the analogue of a
@@ -514,6 +540,10 @@ add_end <- function(x, end) {
 #' the circle.
 #' @param stack logical. Groups and stacks the dots if `TRUE`. Default is `FALSE`.
 #' @param dot_cex,dot_pch,dot_col Plotting arguments for circular dot plot
+#' @param grid logical. Whether to add a grid. Default is `FALSE`.
+#' @param grid.lines,grid.circles numeric. Adds a sequence of straight grid
+#' lines and circles based on angles and radii, respectively. Ignored when
+#' `grid=FALSE`
 #' @param add logical.
 #' @param ... Additional arguments passed to [spatstat.explore::rose()].
 #'
@@ -538,7 +568,7 @@ add_end <- function(x, end) {
 #'
 #' @examples
 #' x <- rvm(100, mean = 90, k = 5)
-#' rose(x, axial = FALSE, border = TRUE)
+#' rose(x, axial = FALSE, border = TRUE, grid = TRUE)
 #'
 #' data("san_andreas") #'
 #' rose(san_andreas$azi, main = "equal area")
@@ -559,6 +589,7 @@ rose <- function(x, weights = NULL, binwidth = NULL, bins = NULL, axial = TRUE,
                  at = seq(0, 360 - 45, 45), cborder = TRUE, labels = TRUE,
                  col = "grey", dots = FALSE, dot_pch = 1, dot_cex = 1,
                  dot_col = "slategrey", stack = FALSE, jitter_factor = 0,
+                 grid = FALSE, grid.lines = seq(0, 135, 45), grid.circles = seq(.2, 1, .2),
                  add = FALSE, ...) {
   if (!add) {
     if (missing(main) || is.null(main)) {
@@ -567,12 +598,16 @@ rose <- function(x, weights = NULL, binwidth = NULL, bins = NULL, axial = TRUE,
     circular_plot(main = main, labels = labels, at = at, cborder = cborder)
   }
 
+  if (grid) {
+    rose_grid(angles = grid.lines, radii = grid.circles)
+  }
+
   if (axial) {
     x <- x %% 180
-    x[x >= 180] <- 180 - 2 * .Machine$double.eps
+    # x[x >= 180] <- 180 - 2 * .Machine$double.eps
   } else {
     x <- x %% 360
-    x[x >= 360] <- 360 - 4 * .Machine$double.eps
+    # x[x >= 360] <- 360 - 4 * .Machine$double.eps
   }
 
   freqs <- rose_freq(
@@ -678,6 +713,7 @@ rose_fan <- function(x, d, radius = 1, axial = TRUE, add = TRUE, ...) {
 #' Either 95% confidence interval (`"CI"`, the default), Fishers confidence interval (`"fisher"`), the circular
 #' standard deviation (`"sd"`), the Quasi interquartile range on the circle
 #' (`"IQR"`), or the sampke median deviation (`"mdev"`). `NULL` if no fan should be drawn.
+#' @param f factor applied on spread. `1` by default.
 #' @param avg.col color for the average line
 #' @param avg.lty line type of the average line
 #' @param avg.lwd  line width of the average line
@@ -703,8 +739,9 @@ rose_fan <- function(x, d, radius = 1, axial = TRUE, add = TRUE, ...) {
 #' rose(san_andreas$azi, weights = 1 / san_andreas$unc, muci = FALSE)
 #' rose_stats(san_andreas$azi, weights = 1 / san_andreas$unc, avg = "sample_median", spread = "mdev")
 rose_stats <- function(x, weights = NULL, axial = TRUE, avg = c("mean", "median", "sample_median"), spread = c("CI", "fisher", "sd", "IQR", "mdev"),
-                       avg.col = "#85112AFF", avg.lty = 2, avg.lwd = 1.5,
-                       spread.col = ggplot2::alpha("#85112AFF", .2), spread.border = FALSE, spread.lty = NULL, spread.lwd = NULL, add = TRUE, ...) {
+                       f = 1,
+                       avg.col = "#B63679FF", avg.lty = 2, avg.lwd = 1.5,
+                       spread.col = ggplot2::alpha("#B63679FF", .2), spread.border = FALSE, spread.lty = NULL, spread.lwd = NULL, add = TRUE, ...) {
   avg <- match.arg(avg)
   mu <- switch(avg,
     mean = circular_mean(x, weights, axial),
@@ -725,7 +762,7 @@ rose_stats <- function(x, weights = NULL, axial = TRUE, avg = c("mean", "median"
       IQR = circular_IQR(x, weights, axial),
       mdev = circular_sample_median_deviation(x, axial)
     )
-    rose_fan(mu, 2 * ci,
+    rose_fan(mu, f * ci,
       radius = 1.1, axial = axial, col = spread.col,
       border = spread.border, lty = spread.lty, lwd = spread.lwd,
       add = add, ...
@@ -734,12 +771,12 @@ rose_stats <- function(x, weights = NULL, axial = TRUE, avg = c("mean", "median"
 
   rose_line(mu,
     radius = 1.1, axial = axial, col = avg.col, lty = avg.lty,
-    lwd = avg.lwd, add = add, ...
+    lwd = avg.lwd, add = TRUE, ...
   )
   invisible(c(mu, ci))
 }
 
-# Dot plot ---------------------------------------------------------------------
+# Dot Plot ---------------------------------------------------------------------
 
 
 #' Add Points to a Circular Plot
@@ -915,7 +952,7 @@ circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shr
 }
 
 
-#' Circular density plot
+#' Circular Density Plot
 #'
 #' Plot the multiples of a von Mises density distribution
 #'
@@ -925,9 +962,10 @@ circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shr
 #' @param axial Logical. Whether data are uniaxial (`axial=FALSE`)
 #' or biaxial (`TRUE`, the default).
 #' @param n the number of equally spaced points at which the density is to be estimated.
-#' @param norm_density logical. Normalize the density?
+#' @param norm.density logical. Normalize the density?
 #' @param scale radius of plotted circle. Default is `1.1`.
 #' @param shrink parameter that controls the size of the plotted function. Default is 1.
+#' @param grid logical. Whether a grid should be added.
 #' @param ... Further graphical parameters may also be supplied as arguments.
 #' @param add logical. Add to existing plot? (`TRUE` by default).
 #' @inheritParams circular_plot
@@ -938,12 +976,18 @@ circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shr
 #'
 #' @examples
 #' rose(san_andreas$azi, dots = TRUE, stack = TRUE, dot_cex = 0.5, dot_pch = 21)
-#' plot_density(san_andreas$azi, kappa = 10, col = "seagreen", shrink = 1.5)
-#' plot_density(san_andreas$azi, kappa = 10, col = "seagreen", add = FALSE, scale = .6)
-plot_density <- function(x, kappa, axial = TRUE, n = 512, norm_density = TRUE, ...,
+#' plot_density(san_andreas$azi,
+#'   kappa = 100, col = "#51127CFF", shrink = 1.5,
+#'   norm.density = FALSE
+#' )
+#' plot_density(san_andreas$azi,
+#'   kappa = 100, col = "#51127CFF", add = FALSE,
+#'   scale = .5, shrink = 2, norm.density = TRUE, grid = TRUE
+#' )
+plot_density <- function(x, kappa, axial = TRUE, n = 512, norm.density = FALSE, ...,
                          scale = 1.1, shrink = 1,
                          add = TRUE, main = NULL, labels = TRUE,
-                         at = seq(0, 360 - 45, 45), cborder = TRUE) {
+                         at = seq(0, 360 - 45, 45), cborder = TRUE, grid = FALSE) {
   if (!add) {
     if (missing(main) || is.null(main)) {
       main <- spatstat.utils::short.deparse(substitute(x))
@@ -951,10 +995,16 @@ plot_density <- function(x, kappa, axial = TRUE, n = 512, norm_density = TRUE, .
     circular_plot(main = main, labels = labels, at = at, cborder = cborder)
   }
 
+  if (grid) {
+    rose_grid(seq(0, 135, 45), seq(.2, 1, .2))
+  }
 
   f <- as.numeric(axial) + 1
   d <- circular_density(x, kappa = kappa, n = n, axial = axial)
-  if (norm_density) d / max(d)
+  if (norm.density) {
+    d <- d / max(d)
+    # shrink = 1/scale
+  }
   circular_lines(seq(0, 360, length = f * n), rep(d, f), axial = FALSE, n, offset = scale, shrink = shrink, ...)
   invisible(d)
 }
@@ -962,14 +1012,14 @@ plot_density <- function(x, kappa, axial = TRUE, n = 512, norm_density = TRUE, .
 
 
 
-#' Plotting stress analysis results
+#' Plotting Stress Analysis Results
 #'
 #' Creates a set of plots including
 #' the azimuth as a function of the distance to the plate boundary,
 #' the Norm Chi-squared as a function of the distance to the plate boundary,
 #' the circular distance (and dispersion) a function of the distance to the
-#' plate boundary, and a rose diagram of the frequency distribution of the
-#' azimuths.
+#' plate boundary, a von-Mises QQ plot, and a rose diagram of the
+#' quality-weighted frequency distribution of the azimuths.
 #'
 #' @param azi numeric. Azimuth of \eqn{\sigma_{Hmax}}{SHmax}
 #' @param distance numeric. Distance to plate boundary
@@ -986,7 +1036,7 @@ plot_density <- function(x, kappa, axial = TRUE, n = 512, norm_density = TRUE, .
 #'
 #' @seealso [PoR_shmax()], [distance_from_pb()], [circular_mean()],
 #' [circular_dispersion()], [confidence_interval_fisher()], [norm_chisq()],
-#' [weighted_rayleigh()]
+#' [weighted_rayleigh()], [vm_qqplot()]
 #'
 #' @details
 #' Plot 1 shows the transformed azimuths as a function of the distance to the
@@ -1120,7 +1170,7 @@ quick_plot <- function(
   graphics::points(azi ~ distance, data = t2, col = t2$regime)
 
   ## roll statistics
-  graphics::lines(roll_mean ~ distance, data = t, type = "S", col = "#85112AFF")
+  graphics::lines(roll_mean ~ distance, data = t, type = "S", col = "#B63679FF")
 
   ## predicted az
   graphics::abline(h = unique(prd), col = "black", lty = 2)
@@ -1144,7 +1194,7 @@ quick_plot <- function(
     roll_nchisq ~ distance,
     data = t,
     type = "S",
-    col = "#85112AFF"
+    col = "#B63679FF"
   )
   graphics::abline(h = .15, col = "black", lty = 2)
 
@@ -1167,9 +1217,12 @@ quick_plot <- function(
   graphics::points(cdist ~ distance,
     data = t, col = t$regime
   )
-  graphics::lines(roll_disp ~ distance, data = t, type = "S", col = "#85112AFF")
+  graphics::lines(roll_disp ~ distance, data = t, type = "S", col = "#B63679FF")
   # graphics::abline(h = disp, col = "black", lty = 2) # dispersion
 
+  # von Mises QQ plot
+  grDevices::dev.new()
+  vm_qqplot(azi, axial = FALSE, pch = 20)
 
   # rose plot
   grDevices::dev.new()
@@ -1181,11 +1234,11 @@ quick_plot <- function(
     mtext = "PoR"
   )
   # rose_stats(azi, weights = 1 / unc)
-  rose_line(prd, radius = 1.1, col = "#009E73") # show the predicted direction
+  rose_line(prd, radius = 1.1, col = "#FB8861FF") # show the predicted direction
   grDevices::palette("default")
 }
 
-#' Plot data in PoR map
+#' Plot Data in PoR Map
 #'
 #' @param x,pb `sf` objects of the data points and the plate
 #' boundary geometries in the geographical coordinate system
